const types = ['checkbox', 'textarea', 'input'];
function getFormByIdOrClosest(element) {
    const formId = element.getAttribute('form');
    const formElement = formId ? document.getElementById(formId) : element.closest('form');
    return formElement instanceof HTMLFormElement ? formElement : null;
}
function addHiddenInput(hostingForm, { name, value }, hiddenType) {
    const hiddenInput = document.createElement(hiddenType);
    hiddenInput.style.display = 'none';
    hiddenInput.setAttribute('name', name);
    hiddenInput.defaultValue = value;
    hostingForm.appendChild(hiddenInput);
    return hiddenInput;
}
function setValueAndValidity(inputField, value, validationMessage = '') {
    if (!inputField) {
        return;
    }
    inputField.value = value;
    inputField.setCustomValidity(validationMessage);
}
export function addInputToForm(inputElement, hiddenType = 'input') {
    const hostingForm = getFormByIdOrClosest(inputElement);
    if (!hostingForm || !inputElement) {
        return;
    }
    inputElement.hiddenInput = addHiddenInput(hostingForm, inputElement, hiddenType);
    setValueAndValidity(inputElement.hiddenInput, inputElement.value, inputElement.formElement.validationMessage);
    hostingForm.addEventListener('reset', () => {
        var _a, _b;
        inputElement.value = inputElement.formElement.value = (_b = (_a = inputElement.hiddenInput) === null || _a === void 0 ? void 0 : _a.defaultValue) !== null && _b !== void 0 ? _b : '';
        setValueAndValidity(inputElement.hiddenInput, inputElement.value, inputElement.formElement.validationMessage);
    });
    inputElement.hiddenInput.addEventListener('invalid', (event) => {
        event.stopPropagation();
        event.preventDefault();
    });
    inputElement.addEventListener('change', () => {
        setValueAndValidity(inputElement.hiddenInput, inputElement.value, inputElement.formElement.validationMessage);
    });
    inputElement.addEventListener('input', () => {
        setValueAndValidity(inputElement.hiddenInput, inputElement.value, inputElement.formElement.validationMessage);
    });
}
//# sourceMappingURL=form-association.js.map